.. _mock-api-reference:

API Reference
=============

.. autoclass:: mock_vws.MockVWS
   :members:
   :undoc-members:

.. TODO why does this error only with :undoc-members:

.. autoclass:: mock_vws.target.TargetDict
   :members:
   :undoc-members:

.. autoclass:: mock_vws.target.Target
   :members:
   :undoc-members:

.. autoclass:: mock_vws.states.States
   :members:
   :undoc-members:

.. autoclass:: mock_vws.database.DatabaseDict
   :members:
   :undoc-members:

.. autoclass:: mock_vws.database.VuforiaDatabase
   :members:
   :undoc-members:
